olekps
======

.. image:: https://discord.com/api/guilds/972499131044069396/embed.png
   :target: https://discord.gg/GChBnwVEHv
   :alt: Discord server invite


olekps libraly


Installing
~~~~~~~~~~



.. code:: sh

    # Linux/macOS
    pip3 install -U olekps

    # Windows
    pip install -U olekps


author
~~~~~~

.. code:: py

   import olekps
   from oleps import *

   print()
